pub struct ExecutionOutput<T> { /* private fields */ }Expand description
Output value paired with the receipt for its execution.
Implementations
Sourceimpl<T> ExecutionOutput<T>
impl<T> ExecutionOutput<T>
Sourcepub const fn new(output: T, receipt: ExecutionReceipt) -> Self
pub const fn new(output: T, receipt: ExecutionReceipt) -> Self
Creates an output/receipt pair.
Sourcepub const fn receipt(&self) -> &ExecutionReceipt
pub const fn receipt(&self) -> &ExecutionReceipt
Borrows the execution receipt.
Sourcepub fn into_parts(self) -> (T, ExecutionReceipt)
pub fn into_parts(self) -> (T, ExecutionReceipt)
Splits the output and receipt without cloning either value.
Sourcepub fn into_output(self) -> T
pub fn into_output(self) -> T
Returns only the algorithm output.
Sourcepub fn map<U>(self, map: impl FnOnce(T) -> U) -> ExecutionOutput<U>
pub fn map<U>(self, map: impl FnOnce(T) -> U) -> ExecutionOutput<U>
Maps the output while preserving its execution receipt.