pub struct PointCloudBuilder { /* private fields */ }Expand description
Builds point clouds field-by-field.
Implementations
Sourceimpl PointCloudBuilder
impl PointCloudBuilder
Sourcepub fn new(schema: PointSchema) -> Self
pub fn new(schema: PointSchema) -> Self
Creates a builder from a schema.
Sourcepub fn metadata(self, metadata: SpatialMetadata) -> Self
pub fn metadata(self, metadata: SpatialMetadata) -> Self
Sets spatial metadata.
Sourcepub fn push_point<I>(&mut self, values: I) -> SpatialResult<()>where
I: IntoIterator<Item = f32>,
pub fn push_point<I>(&mut self, values: I) -> SpatialResult<()>where
I: IntoIterator<Item = f32>,
Appends one point by field values in schema order.
Each field value must be a scalar convertible to the field dtype.
Sourcepub fn build(self) -> SpatialResult<PointCloud>
pub fn build(self) -> SpatialResult<PointCloud>
Builds the final point cloud.