TransferStats

Struct TransferStats 

pub struct TransferStats { /* private fields */ }
Byte accounting for explicit execution transfers.

Implementations

Source

impl TransferStats

pub fn record(&mut self, direction: TransferDirection, bytes: u64)

Records bytes transferred in the given direction.

pub const fn host_to_device_bytes(self) -> u64

Returns bytes copied from host memory into device memory.

pub const fn device_to_device_bytes(self) -> u64

Returns bytes copied between buffers on a device.

pub const fn device_to_host_bytes(self) -> u64

Returns bytes copied from device memory into host memory.