pub struct TransferStats { /* private fields */ }Expand description
Byte accounting for explicit execution transfers.
Implementations
Sourceimpl TransferStats
impl TransferStats
Sourcepub fn record(&mut self, direction: TransferDirection, bytes: u64)
pub fn record(&mut self, direction: TransferDirection, bytes: u64)
Records bytes transferred in the given direction.
Sourcepub const fn host_to_device_bytes(self) -> u64
pub const fn host_to_device_bytes(self) -> u64
Returns bytes copied from host memory into device memory.
Sourcepub const fn device_to_device_bytes(self) -> u64
pub const fn device_to_device_bytes(self) -> u64
Returns bytes copied between buffers on a device.
Sourcepub const fn device_to_host_bytes(self) -> u64
pub const fn device_to_host_bytes(self) -> u64
Returns bytes copied from device memory into host memory.